Sphere class

Stateful widget that automatically rotates the sphere

Inheritance

Constructors

Sphere({Key? key, required List<Widget> children, required double size, double rotationX = 30.0, double rotationY = 30.0, bool alphaEnabled = true})
const
Sphere.gesture({Key? key, required List<Widget> children, required double size, bool alphaEnabled = true})
const
Sphere.rotate({Key? key, required List<Widget> children, required double size, bool isRotationX = true, bool isRotationY = true, double rotationYSpeed = 30.0, bool alphaEnabled = true, bool isRotate = true})
const

Properties

alphaEnabled bool
final
children List<Widget>
final
hashCode int
The hash code for this object.
no setterinherited
isGesture bool
final
isRotate bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
rotationX double
final
rotationY double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<Sphere>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited